pub struct Create {
pub metadata: Pubkey,
pub master_edition: Option<Pubkey>,
pub mint: (Pubkey, bool),
pub authority: Pubkey,
pub payer: Pubkey,
pub update_authority: (Pubkey, bool),
pub system_program: Pubkey,
pub sysvar_instructions: Pubkey,
pub spl_token_program: Option<Pubkey>,
}Expand description
Accounts.
Fields
metadata: PubkeyUnallocated metadata account with address as pda of [‘metadata’, program id, mint id]
master_edition: Option<Pubkey>Unallocated edition account with address as pda of [‘metadata’, program id, mint, ‘edition’]
mint: (Pubkey, bool)Mint of token asset
Mint authority
payer: PubkeyPayer
Update authority for the metadata account
system_program: PubkeySystem program
sysvar_instructions: PubkeyInstructions sysvar account
spl_token_program: Option<Pubkey>SPL Token program
Implementations
Sourceimpl Create
impl Create
pub fn instruction(&self, args: CreateInstructionArgs) -> Instruction
pub fn instruction_with_remaining_accounts( &self, args: CreateInstructionArgs, remaining_accounts: &[AccountMeta], ) -> Instruction