pub struct CreateCpiAccounts<'a, 'b> {
pub metadata: &'b AccountInfo<'a>,
pub master_edition: Option<&'b AccountInfo<'a>>,
pub mint: (&'b AccountInfo<'a>, bool),
pub authority: &'b AccountInfo<'a>,
pub payer: &'b AccountInfo<'a>,
pub update_authority: (&'b AccountInfo<'a>, bool),
pub system_program: &'b AccountInfo<'a>,
pub sysvar_instructions: &'b AccountInfo<'a>,
pub spl_token_program: Option<&'b AccountInfo<'a>>,
}Expand description
create CPI accounts.
Fields
metadata: &'b AccountInfo<'a>Unallocated metadata account with address as pda of [‘metadata’, program id, mint id]
master_edition: Option<&'b AccountInfo<'a>>Unallocated edition account with address as pda of [‘metadata’, program id, mint, ‘edition’]
mint: (&'b AccountInfo<'a>, bool)Mint of token asset
Mint authority
payer: &'b AccountInfo<'a>Payer
Update authority for the metadata account
system_program: &'b AccountInfo<'a>System program
sysvar_instructions: &'b AccountInfo<'a>Instructions sysvar account
spl_token_program: Option<&'b AccountInfo<'a>>SPL Token program