pub struct CreateInstructionArgs {
pub create_args: CreateArgs,
}Fields
create_args: CreateArgsTrait Implementations
Sourceimpl BorshDeserialize for CreateInstructionArgswhere
CreateArgs: BorshDeserialize,
impl BorshDeserialize for CreateInstructionArgswhere
CreateArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateInstructionArgswhere
CreateArgs: BorshSerialize,
impl BorshSerialize for CreateInstructionArgswhere
CreateArgs: BorshSerialize,
Sourceimpl Clone for CreateInstructionArgs
impl Clone for CreateInstructionArgs
Sourcefn clone(&self) -> CreateInstructionArgs
fn clone(&self) -> CreateInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateInstructionArgs
impl Debug for CreateInstructionArgs
Sourceimpl PartialEq for CreateInstructionArgs
impl PartialEq for CreateInstructionArgs
impl Eq for CreateInstructionArgs
impl StructuralPartialEq for CreateInstructionArgs