CreateMetadataAccountV3CpiBuilder

Struct CreateMetadataAccountV3CpiBuilder 

pub struct CreateMetadataAccountV3CpiBuilder<'a, 'b> { /* private fields */ }
Instruction builder for CreateMetadataAccountV3 via CPI.

Accounts:

  1. [writable] metadata
  2. [] mint
  3. [signer] mint_authority
  4. [writable, signer] payer
  5. [signer] update_authority
  6. [] system_program
  7. [optional] rent

Implementations

Source

impl<'a, 'b> CreateMetadataAccountV3CpiBuilder<'a, 'b>

pub fn new(program: &'b AccountInfo<'a>) -> Self

pub fn metadata(&mut self, metadata: &'b AccountInfo<'a>) -> &mut Self

Metadata key (pda of [‘metadata’, program id, mint id])

pub fn mint(&mut self, mint: &'b AccountInfo<'a>) -> &mut Self

Mint of token asset

pub fn mint_authority( &mut self, mint_authority: &'b AccountInfo<'a>, ) -> &mut Self

Mint authority

pub fn payer(&mut self, payer: &'b AccountInfo<'a>) -> &mut Self

payer

pub fn update_authority( &mut self, update_authority: &'b AccountInfo<'a>, as_signer: bool, ) -> &mut Self

update authority info

pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self

System program

pub fn rent(&mut self, rent: Option<&'b AccountInfo<'a>>) -> &mut Self

[optional account] Rent info

pub fn data(&mut self, data: DataV2) -> &mut Self

pub fn is_mutable(&mut self, is_mutable: bool) -> &mut Self

pub fn collection_details( &mut self, collection_details: CollectionDetails, ) -> &mut Self

[optional argument]

pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self

Add an additional account to the instruction.

pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self

Add additional accounts to the instruction.

Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not, and a bool indicating whether the account is a signer or not.

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult