pub struct CreateMetadataAccountV3InstructionArgs {
pub data: DataV2,
pub is_mutable: bool,
pub collection_details: Option<CollectionDetails>,
}Fields
data: DataV2is_mutable: boolcollection_details: Option<CollectionDetails>Trait Implementations
Sourceimpl BorshDeserialize for CreateMetadataAccountV3InstructionArgs
impl BorshDeserialize for CreateMetadataAccountV3InstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateMetadataAccountV3InstructionArgs
impl Clone for CreateMetadataAccountV3InstructionArgs
Sourcefn clone(&self) -> CreateMetadataAccountV3InstructionArgs
fn clone(&self) -> CreateMetadataAccountV3InstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateMetadataAccountV3InstructionArgs
impl PartialEq for CreateMetadataAccountV3InstructionArgs
Sourcefn eq(&self, other: &CreateMetadataAccountV3InstructionArgs) -> bool
fn eq(&self, other: &CreateMetadataAccountV3InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateMetadataAccountV3InstructionArgs
impl StructuralPartialEq for CreateMetadataAccountV3InstructionArgs