pub struct CreateV1Builder { /* private fields */ }Expand description
Instruction builder for CreateV1.
Accounts:
[writable]metadata[writable, optional]master_edition[writable, signer]mint[signer]authority[writable, signer]payer[signer]update_authority[optional]system_program (default to11111111111111111111111111111111)[optional]sysvar_instructions (default toSysvar1nstructions1111111111111111111111111)[optional]spl_token_program
Implementations
Sourceimpl CreateV1Builder
impl CreateV1Builder
pub fn new() -> Self
Sourcepub fn metadata(&mut self, metadata: Pubkey) -> &mut Self
pub fn metadata(&mut self, metadata: Pubkey) -> &mut Self
Unallocated metadata account with address as pda of [‘metadata’, program id, mint id]
Sourcepub fn master_edition(&mut self, master_edition: Option<Pubkey>) -> &mut Self
pub fn master_edition(&mut self, master_edition: Option<Pubkey>) -> &mut Self
[optional account]
Unallocated edition account with address as pda of [‘metadata’, program id, mint, ‘edition’]
Mint authority
Update authority for the metadata account
Sourcepub fn system_program(&mut self, system_program: Pubkey) -> &mut Self
pub fn system_program(&mut self, system_program: Pubkey) -> &mut Self
[optional account, default to '11111111111111111111111111111111']
System program
Sourcepub fn sysvar_instructions(&mut self, sysvar_instructions: Pubkey) -> &mut Self
pub fn sysvar_instructions(&mut self, sysvar_instructions: Pubkey) -> &mut Self
[optional account, default to 'Sysvar1nstructions1111111111111111111111111']
Instructions sysvar account
Sourcepub fn spl_token_program(
&mut self,
spl_token_program: Option<Pubkey>,
) -> &mut Self
pub fn spl_token_program( &mut self, spl_token_program: Option<Pubkey>, ) -> &mut Self
[optional account]
SPL Token program
pub fn name(&mut self, name: String) -> &mut Self
Sourcepub fn symbol(&mut self, symbol: String) -> &mut Self
pub fn symbol(&mut self, symbol: String) -> &mut Self
[optional argument, defaults to 'String::from("")']
pub fn uri(&mut self, uri: String) -> &mut Self
pub fn seller_fee_basis_points( &mut self, seller_fee_basis_points: u16, ) -> &mut Self
Sourcepub fn primary_sale_happened(
&mut self,
primary_sale_happened: bool,
) -> &mut Self
pub fn primary_sale_happened( &mut self, primary_sale_happened: bool, ) -> &mut Self
[optional argument, defaults to 'false']
Sourcepub fn is_mutable(&mut self, is_mutable: bool) -> &mut Self
pub fn is_mutable(&mut self, is_mutable: bool) -> &mut Self
[optional argument, defaults to 'true']
Sourcepub fn token_standard(&mut self, token_standard: TokenStandard) -> &mut Self
pub fn token_standard(&mut self, token_standard: TokenStandard) -> &mut Self
[optional argument, defaults to 'TokenStandard::NonFungible']
Sourcepub fn collection(&mut self, collection: Collection) -> &mut Self
pub fn collection(&mut self, collection: Collection) -> &mut Self
[optional argument]
Sourcepub fn collection_details(
&mut self,
collection_details: CollectionDetails,
) -> &mut Self
pub fn collection_details( &mut self, collection_details: CollectionDetails, ) -> &mut Self
[optional argument]
Sourcepub fn print_supply(&mut self, print_supply: PrintSupply) -> &mut Self
pub fn print_supply(&mut self, print_supply: PrintSupply) -> &mut Self
[optional argument]
Sourcepub fn add_remaining_account(&mut self, account: AccountMeta) -> &mut Self
pub fn add_remaining_account(&mut self, account: AccountMeta) -> &mut Self
Add an aditional account to the instruction.
Sourcepub fn add_remaining_accounts(&mut self, accounts: &[AccountMeta]) -> &mut Self
pub fn add_remaining_accounts(&mut self, accounts: &[AccountMeta]) -> &mut Self
Add additional accounts to the instruction.