DelegateProgrammableConfigV1CpiBuilder

Struct DelegateProgrammableConfigV1CpiBuilder 

pub struct DelegateProgrammableConfigV1CpiBuilder<'a, 'b> { /* private fields */ }
Instruction builder for DelegateProgrammableConfigV1 via CPI.

Accounts:

  1. [writable, optional] delegate_record
  2. [] delegate
  3. [writable] metadata
  4. [optional] master_edition
  5. [writable, optional] token_record
  6. [] mint
  7. [writable, optional] token
  8. [signer] authority
  9. [writable, signer] payer
  10. [] system_program
  11. [] sysvar_instructions
  12. [optional] spl_token_program
  13. [optional] authorization_rules_program
  14. [optional] authorization_rules

Implementations

Source

impl<'a, 'b> DelegateProgrammableConfigV1CpiBuilder<'a, 'b>

pub fn new(program: &'b AccountInfo<'a>) -> Self

pub fn delegate_record( &mut self, delegate_record: Option<&'b AccountInfo<'a>>, ) -> &mut Self

[optional account] Delegate record account

pub fn delegate(&mut self, delegate: &'b AccountInfo<'a>) -> &mut Self

Owner of the delegated account

pub fn metadata(&mut self, metadata: &'b AccountInfo<'a>) -> &mut Self

Metadata account

pub fn master_edition( &mut self, master_edition: Option<&'b AccountInfo<'a>>, ) -> &mut Self

[optional account] Master Edition account

pub fn token_record( &mut self, token_record: Option<&'b AccountInfo<'a>>, ) -> &mut Self

[optional account] Token record account

pub fn mint(&mut self, mint: &'b AccountInfo<'a>) -> &mut Self

Mint of metadata

pub fn token(&mut self, token: Option<&'b AccountInfo<'a>>) -> &mut Self

[optional account] Token account of mint

pub fn authority(&mut self, authority: &'b AccountInfo<'a>) -> &mut Self

Update authority or token owner

pub fn payer(&mut self, payer: &'b AccountInfo<'a>) -> &mut Self

Payer

pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self

System Program

pub fn sysvar_instructions( &mut self, sysvar_instructions: &'b AccountInfo<'a>, ) -> &mut Self

Instructions sysvar account

pub fn spl_token_program( &mut self, spl_token_program: Option<&'b AccountInfo<'a>>, ) -> &mut Self

[optional account] SPL Token Program

pub fn authorization_rules_program( &mut self, authorization_rules_program: Option<&'b AccountInfo<'a>>, ) -> &mut Self

[optional account] Token Authorization Rules Program

pub fn authorization_rules( &mut self, authorization_rules: Option<&'b AccountInfo<'a>>, ) -> &mut Self

[optional account] Token Authorization Rules account

pub fn authorization_data( &mut self, authorization_data: AuthorizationData, ) -> &mut Self

[optional argument]

pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self

Add an additional account to the instruction.

pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self

Add additional accounts to the instruction.

Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not, and a bool indicating whether the account is a signer or not.

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult