PrintV2

Struct PrintV2 

pub struct PrintV2 {
Show 20 fields pub edition_metadata: Pubkey, pub edition: Pubkey, pub edition_mint: (Pubkey, bool), pub edition_token_account_owner: Pubkey, pub edition_token_account: Pubkey, pub edition_mint_authority: Pubkey, pub edition_token_record: Option<Pubkey>, pub master_edition: Pubkey, pub edition_marker_pda: Pubkey, pub payer: Pubkey, pub master_token_account_owner: (Pubkey, bool), pub master_token_account: Pubkey, pub master_metadata: Pubkey, pub update_authority: Pubkey, pub spl_token_program: Pubkey, pub spl_ata_program: Pubkey, pub sysvar_instructions: Pubkey, pub system_program: Pubkey, pub holder_delegate_record: Option<Pubkey>, pub delegate: Option<Pubkey>,
}
Accounts.

Fields

edition_metadata: Pubkey

New Metadata key (pda of [‘metadata’, program id, mint id])

edition: Pubkey

New Edition (pda of [‘metadata’, program id, mint id, ‘edition’])

edition_mint: (Pubkey, bool)

Mint of new token - THIS WILL TRANSFER AUTHORITY AWAY FROM THIS KEY

edition_token_account_owner: Pubkey

Owner of the token account of new token

edition_token_account: Pubkey

Token account of new token

edition_mint_authority: Pubkey

Mint authority of new mint

edition_token_record: Option<Pubkey>

Token record account

master_edition: Pubkey

Master Record Edition V2 (pda of [‘metadata’, program id, master metadata mint id, ‘edition’])

edition_marker_pda: Pubkey

Edition pda to mark creation - will be checked for pre-existence. (pda of [‘metadata’, program id, master metadata mint id, ‘edition’, edition_number]) where edition_number is NOT the edition number you pass in args but actually edition_number = floor(edition/EDITION_MARKER_BIT_SIZE).

payer: Pubkey

payer

master_token_account_owner: (Pubkey, bool)

owner of token account containing master token

master_token_account: Pubkey

token account containing token from master metadata mint

master_metadata: Pubkey

Master record metadata account

update_authority: Pubkey

The update authority of the master edition.

spl_token_program: Pubkey

Token program

spl_ata_program: Pubkey

SPL Associated Token Account program

sysvar_instructions: Pubkey

Instructions sysvar account

system_program: Pubkey

System program

holder_delegate_record: Option<Pubkey>

The Delegate Record authorizing escrowless edition printing

delegate: Option<Pubkey>

The authority printing the edition for a delegated print

Implementations