pub struct Resize {
pub metadata: Pubkey,
pub edition: Pubkey,
pub mint: Pubkey,
pub payer: (Pubkey, bool),
pub authority: Option<Pubkey>,
pub token: Option<Pubkey>,
pub system_program: Pubkey,
}Expand description
Accounts.
Fields
metadata: PubkeyThe metadata account of the digital asset
edition: PubkeyThe master edition or edition account of the digital asset, an uninitialized account for fungible assets
mint: PubkeyMint of token asset
payer: (Pubkey, bool)The recipient of the excess rent and authority if the authority account is not present
Owner of the asset for (p)NFTs, or mint authority for fungible assets, if different from the payer
token: Option<Pubkey>Token or Associated Token account
system_program: PubkeySystem program
Implementations
Sourceimpl Resize
impl Resize
pub fn instruction(&self) -> Instruction
pub fn instruction_with_remaining_accounts( &self, remaining_accounts: &[AccountMeta], ) -> Instruction