ResizeCpi

Struct ResizeCpi 

pub struct ResizeCpi<'a, 'b> {
    pub __program: &'b AccountInfo<'a>,
    pub metadata: &'b AccountInfo<'a>,
    pub edition: &'b AccountInfo<'a>,
    pub mint: &'b AccountInfo<'a>,
    pub payer: (&'b AccountInfo<'a>, bool),
    pub authority: Option<&'b AccountInfo<'a>>,
    pub token: Option<&'b AccountInfo<'a>>,
    pub system_program: &'b AccountInfo<'a>,
}
resize CPI instruction.

Fields

__program: &'b AccountInfo<'a>

The program to invoke.

metadata: &'b AccountInfo<'a>

The metadata account of the digital asset

edition: &'b AccountInfo<'a>

The master edition or edition account of the digital asset, an uninitialized account for fungible assets

mint: &'b AccountInfo<'a>

Mint of token asset

payer: (&'b AccountInfo<'a>, bool)

The recipient of the excess rent and authority if the authority account is not present

authority: Option<&'b AccountInfo<'a>>

Owner of the asset for (p)NFTs, or mint authority for fungible assets, if different from the payer

token: Option<&'b AccountInfo<'a>>

Token or Associated Token account

system_program: &'b AccountInfo<'a>

System program

Implementations

Source

impl<'a, 'b> ResizeCpi<'a, 'b>

pub fn new( program: &'b AccountInfo<'a>, accounts: ResizeCpiAccounts<'a, 'b>, ) -> Self

pub fn invoke(&self) -> ProgramResult

pub fn invoke_with_remaining_accounts( &self, remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult

pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult

pub fn invoke_signed_with_remaining_accounts( &self, signers_seeds: &[&[&[u8]]], remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult