pub struct SetCollectionSizeCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for SetCollectionSize via CPI.
Accounts:
[writable]collection_metadata[writable, signer]collection_authority[]collection_mint[optional]collection_authority_record
Implementations
Sourceimpl<'a, 'b> SetCollectionSizeCpiBuilder<'a, 'b>
impl<'a, 'b> SetCollectionSizeCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
Sourcepub fn collection_metadata(
&mut self,
collection_metadata: &'b AccountInfo<'a>,
) -> &mut Self
pub fn collection_metadata( &mut self, collection_metadata: &'b AccountInfo<'a>, ) -> &mut Self
Collection Metadata account
Collection Update authority
Sourcepub fn collection_mint(
&mut self,
collection_mint: &'b AccountInfo<'a>,
) -> &mut Self
pub fn collection_mint( &mut self, collection_mint: &'b AccountInfo<'a>, ) -> &mut Self
Mint of the Collection
[optional account]
Collection Authority Record PDA
pub fn set_collection_size_args( &mut self, set_collection_size_args: SetCollectionSizeArgs, ) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult