pub struct SetCollectionSizeInstructionArgs {
pub set_collection_size_args: SetCollectionSizeArgs,
}Fields
set_collection_size_args: SetCollectionSizeArgsTrait Implementations
Sourceimpl BorshDeserialize for SetCollectionSizeInstructionArgs
impl BorshDeserialize for SetCollectionSizeInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetCollectionSizeInstructionArgswhere
SetCollectionSizeArgs: BorshSerialize,
impl BorshSerialize for SetCollectionSizeInstructionArgswhere
SetCollectionSizeArgs: BorshSerialize,
Sourceimpl Clone for SetCollectionSizeInstructionArgs
impl Clone for SetCollectionSizeInstructionArgs
Sourcefn clone(&self) -> SetCollectionSizeInstructionArgs
fn clone(&self) -> SetCollectionSizeInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for SetCollectionSizeInstructionArgs
impl PartialEq for SetCollectionSizeInstructionArgs
Sourcefn eq(&self, other: &SetCollectionSizeInstructionArgs) -> bool
fn eq(&self, other: &SetCollectionSizeInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetCollectionSizeInstructionArgs
impl StructuralPartialEq for SetCollectionSizeInstructionArgs