pub struct MintNewEditionFromMasterEditionViaTokenArgs {
pub edition: u64,
}Fields
edition: u64Trait Implementations
Sourceimpl BorshDeserialize for MintNewEditionFromMasterEditionViaTokenArgswhere
u64: BorshDeserialize,
impl BorshDeserialize for MintNewEditionFromMasterEditionViaTokenArgswhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MintNewEditionFromMasterEditionViaTokenArgswhere
u64: BorshSerialize,
impl BorshSerialize for MintNewEditionFromMasterEditionViaTokenArgswhere
u64: BorshSerialize,
Sourceimpl Clone for MintNewEditionFromMasterEditionViaTokenArgs
impl Clone for MintNewEditionFromMasterEditionViaTokenArgs
Sourcefn clone(&self) -> MintNewEditionFromMasterEditionViaTokenArgs
fn clone(&self) -> MintNewEditionFromMasterEditionViaTokenArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for MintNewEditionFromMasterEditionViaTokenArgs
impl PartialEq for MintNewEditionFromMasterEditionViaTokenArgs
Sourcefn eq(&self, other: &MintNewEditionFromMasterEditionViaTokenArgs) -> bool
fn eq(&self, other: &MintNewEditionFromMasterEditionViaTokenArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MintNewEditionFromMasterEditionViaTokenArgs
impl StructuralPartialEq for MintNewEditionFromMasterEditionViaTokenArgs