pub struct Payload {
pub map: HashMap<String, PayloadType>,
}Fields
map: HashMap<String, PayloadType>Trait Implementations
Sourceimpl BorshDeserialize for Payload
impl BorshDeserialize for Payload
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Payload
impl BorshSerialize for Payload
impl Eq for Payload
impl StructuralPartialEq for Payload