pub struct Reservation {
pub address: Pubkey,
pub spots_remaining: u64,
pub total_spots: u64,
}Fields
address: Pubkeyspots_remaining: u64total_spots: u64Trait Implementations
Sourceimpl BorshDeserialize for Reservation
impl BorshDeserialize for Reservation
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Reservation
impl BorshSerialize for Reservation
Sourceimpl Clone for Reservation
impl Clone for Reservation
Sourcefn clone(&self) -> Reservation
fn clone(&self) -> Reservation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Reservation
impl Debug for Reservation
Sourceimpl PartialEq for Reservation
impl PartialEq for Reservation
impl Eq for Reservation
impl StructuralPartialEq for Reservation