pub struct ReservationV1 {
pub address: Pubkey,
pub spots_remaining: u8,
pub total_spots: u8,
}Fields
address: Pubkeyspots_remaining: u8total_spots: u8Trait Implementations
Sourceimpl BorshDeserialize for ReservationV1
impl BorshDeserialize for ReservationV1
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ReservationV1
impl BorshSerialize for ReservationV1
Sourceimpl Clone for ReservationV1
impl Clone for ReservationV1
Sourcefn clone(&self) -> ReservationV1
fn clone(&self) -> ReservationV1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReservationV1
impl Debug for ReservationV1
Sourceimpl PartialEq for ReservationV1
impl PartialEq for ReservationV1
impl Eq for ReservationV1
impl StructuralPartialEq for ReservationV1